class TagsImporter
  attr_accessor :items

  def import
    tags = {}
    taggings = []
    @items.each do |learning_object|
      publisher = learning_object.publisher
      categories = parse_categories learning_object.get_metadata_values_of 'dc.subject.category'
      keywords = learning_object.get_metadata_values_of 'dc.subject.keyword'
      (categories + keywords).each do |tag_name|
        if !tag_exists?(tag_name, tags)
          tags[tag_name] = Tag.new(name: tag_name)
          tag = tags[tag_name]
        else
          tag = Tag.find_by_name tag_name
        end

        unless tagging_exists?(tag, publisher, learning_object)
          taggings << Tagging.new(tag: tag, tagger: publisher, taggable: learning_object)
        end
      end
    end

    Tag.import tags.values
    Tagging.import taggings
  end


  private

  def parse_categories(values)
    tags = []
    values.compact.each { |value| tags << value.split(/::|;|\//) }
    tags.flatten.uniq.map(&:strip)
  end

  def tag_exists? (tag_name, tags)
    !Tag.find_by_name(tag_name).nil? || !tags[tag_name].nil?
  end

  def tagging_exists? (tag, tagger, taggable)
    Tagging.where(tag: tag, tagger: tagger, taggable: taggable).exists?
  end

end
